enableCropping property
Whether to enable the cropping step after taking a photo or picking an image.
Implementation
final bool enableCropping;
Whether to enable the cropping step after taking a photo or picking an image.
final bool enableCropping;