maxFileCount property
The maximum number of files allowed to be selected from the file picker. Set to 0 for unlimited selection.
Implementation
final int maxFileCount;
The maximum number of files allowed to be selected from the file picker. Set to 0 for unlimited selection.
final int maxFileCount;