maxImageCount property
The maximum number of images allowed to be selected from the gallery. Set to 0 for unlimited selection.
Implementation
final int maxImageCount;
The maximum number of images allowed to be selected from the gallery. Set to 0 for unlimited selection.
final int maxImageCount;