AttachmentResult class

Represents the result of a successful attachment acquisition.

Constructors

AttachmentResult({required String path, required AttachmentType type, required String name, int? sizeBytes})
Creates a new AttachmentResult.
const

Properties

file File
Convenience getter to access the File object for the attachment.
no setter
hashCode int
The hash code for this object.
no setterinherited
humanSize String
Returns a human-readable string representation of the file size.
no setter
name String
The display name of the file (including extension).
final
path String
The absolute local filesystem path to the attachment.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes int?
The size of the file in bytes, if available.
final
type AttachmentType
The category of the attachment (image, pdf, or file).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited