AttachmentUIStyle enum

Defines the presentation style of the attachment picker.

Inheritance
Available extensions

Values

bottomSheet → const AttachmentUIStyle

Renders as a standard bottom sheet.

dialog → const AttachmentUIStyle

Renders as a centered dialog.

custom → const AttachmentUIStyle

Indicates a custom implementation using the raw service.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AttachmentUIStyle>
A constant List of the values in this enum, in order of their declaration.