child property
An optional custom child widget to use as the button body. If provided, uses a GestureDetector to wrap this child.
Implementation
final Widget? child;
An optional custom child widget to use as the button body. If provided, uses a GestureDetector to wrap this child.
final Widget? child;