PixelToPdfService class
A singleton service that provides native acquisition capabilities for document scanning, image capture, and file selection.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildPdf(
List< String> imagePaths) → Future<File> -
cropImage(
String imagePath) → Future< File?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pickFile(
) → Future< AttachmentResult?> - Launches the device file picker to select any document or file.
-
pickImage(
{bool enableCropping = true}) → Future< AttachmentResult?> - Picks a single image from the device gallery.
-
pickMultiFiles(
{int? maxCount}) → Future< List< AttachmentResult> > - Picks multiple files from the device storage.
-
pickMultiFromGallery(
{int? maxCount}) → Future< List< AttachmentResult> > - Picks multiple images from the device gallery.
-
scanDocument(
) → Future< AttachmentResult?> - Launches the native document scanner and returns a single PDF file result.
-
takePhoto(
{bool enableCropping = true}) → Future< AttachmentResult?> - Launches the native camera to take a single photo.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → PixelToPdfService
-
The singleton instance of PixelToPdfService.
final